#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 sendfile
version:              0.7.11.6
visibility:           public
id:                   sendfile-0.7.11.6-KV3s7P42hSuJH2px4kkI7X
key:                  sendfile-0.7.11.6-KV3s7P42hSuJH2px4kkI7X
license:              BSD-3-Clause
maintainer:           Jeremy Shaw <jeremy@n-heptane.com>
author:               Matthew Elder <matt@mattelder.org>
stability:            provisional
homepage:             https://github.com/Happstack/sendfile
synopsis:             A portable sendfile library
description:
    A library which exposes zero-copy sendfile functionality in a portable way. If a platform does not support sendfile, a fallback implementation in haskell is provided.

    Currently supported platforms: Windows 2000+ (Native), Linux 2.6+ (Native), FreeBSD (Native), OS-X 10.5+ (Native), Everything else (Portable Haskell code).

category:             Network
abi:                  5affa8f5532eb0909c1991aa34e867b6
exposed:              True
exposed-modules:
    Network.Socket.SendFile Network.Socket.SendFile.Handle
    Network.Socket.SendFile.Iter Network.Socket.SendFile.Portable

hidden-modules:
    Network.Socket.SendFile.Internal Network.Socket.SendFile.Util
    Network.Socket.SendFile.Linux

import-dirs:          /usr/lib/ghc-9.6.6/site-local/sendfile-0.7.11.6
library-dirs:         /usr/lib/ghc-9.6.6/site-local/sendfile-0.7.11.6
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/sendfile-0.7.11.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-sendfile
hs-libraries:         HSsendfile-0.7.11.6-KV3s7P42hSuJH2px4kkI7X
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    network-3.1.4.0-5CNSYfJ9OXEKTDv1UbcApF

haddock-interfaces:   /usr/share/doc/haskell-sendfile/html/sendfile.haddock
haddock-html:         /usr/share/doc/haskell-sendfile/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

